@@ -39,7 +39,7 @@
 #' @section Built-in evaluation strategies:
 #' The \pkg{future} package provides the following built-in backends:
 #'
-#' \itemize{
+#' \describe{
 #'  \item{[`sequential`]:}{
 #'    Resolves futures sequentially in the current \R process, e.g.
 #'    `plan(sequential)`.
@@ -75,16 +75,6 @@
 #' are available on high-performance compute (HPC) clusters, e.g. LSF,
 #' Slurm, TORQUE/PBS, Sun Grid Engine, and OpenLava.
 #'
-#' The following future strategies are _deprecated_ and must not be used:
-#'
-#' \itemize{
-#'  \item{[`multiprocess`]:}{(DEPRECATED since future 1.20.0)
-#'    If multicore evaluation is supported, that will be used,
-#'    otherwise multisession evaluation will be used.
-#'    _Please use `multisession`, or possibly `multicore` instead._
-#'  }
-#' }
-#' 
 #' To "close" any background workers (e.g. `multisession`), change
 #' the plan to something different; `plan(sequential)` is recommended
 #' for this.
@@ -162,40 +152,11 @@ plan <- local({
     if (class[1] == strategy) return(TRUE)
     if (length(class) == 1L) return(FALSE)
     if (class[1] == "tweaked" && class[2] == strategy) return(TRUE)
+    ## Special case for strategy == "multiprocess"
+    if (strategy == "multiprocess" && class[length(class)] == strategy) return(TRUE)
     FALSE
   }
 
-  warn_about_deprecated <- function(stack, strategy, fmtstr, ignore = NULL, defunct = NULL) {
-    for (kk in seq_along(stack)) {
-      if (evaluator_uses(stack[[kk]], strategy)) {
-        if (is.null(ignore)) ignore <- getOption("future.deprecated.ignore")
-        if (!is.element(strategy, ignore)) {
-          if (is.null(defunct)) defunct <- getOption("future.deprecated.defunct")
-          if (is.element(strategy, defunct)) {
-            msg <- sprintf(fmtstr, strategy, "defunct")
-            dfcn <- .Defunct
-          } else {
-            msg <- sprintf(fmtstr, strategy, "deprecated")
-            dfcn <- .Deprecated
-          }
-          dfcn(msg = msg, package = .packageName)
-        }
-      }
-    }
-  }
-
-  warn_about_multiprocess <- function(stack) {
-    warn_about_deprecated(stack, strategy = "multiprocess", fmtstr = sprintf("Strategy '%%s' is %%s in future (>= 1.20.0) [2020-10-30]. Instead, explicitly specify either 'multisession' (recommended) or 'multicore'. Starting with future 1.31.0 [2023-01-31], 'multiprocess' is the same as 'sequential'."))
-  }
-
-  warn_about_remote <- function(stack) {
-    warn_about_deprecated(stack, strategy = "remote", fmtstr = "Strategy '%s' is %s in future (>= 1.30.0) [2022-12-15]. Instead, use plan(cluster, ..., persistent = TRUE).", ignore = "", defunct = "remote")
-  }
-
-  warn_about_transparent <- function(stack) {
-    warn_about_deprecated(stack, strategy = "transparent", fmtstr = "Strategy '%s' is %s in future (>= 1.28.0) [2022-09-02]. It was designed to simplify interactive troubleshooting, but is now superseded by plan(sequential, split = TRUE).", defunct = "transparent")
-  }
-
   warn_about_multicore <- local({
     .warn <- TRUE
 
@@ -302,9 +263,7 @@ plan <- local({
 
     assert_no_disallowed_strategies(newStack)
 
-    warn_about_multiprocess(newStack)
-    warn_about_remote(newStack)
-    warn_about_transparent(newStack)
+    ## Warn about 'multicore' on certain systems
     warn_about_multicore(newStack)
 
     stack <<- newStack
